@@ -1,6 +1,6 @@
 import {LooseParser} from "./state.js"
 import {isDummy} from "./parseutil.js"
-import {tokTypes as tt} from "acorn"
+import {tokTypes as tt, tokContexts as tokContextTypes} from "acorn"
 
 const lp = LooseParser.prototype
 
@@ -42,7 +42,8 @@ lp.parseParenExpression = function() {
 }
 
 lp.parseMaybeAssign = function(noIn) {
-  if (this.toks.isContextual("yield")) {
+  // `yield` should be an identifier reference if it's not in generator functions.
+  if (this.inGenerator && this.toks.isContextual("yield")) {
     let node = this.startNode()
     this.next()
     if (this.semicolon() || this.canInsertSemicolon() || (this.tok.type !== tt.star && !this.tok.type.startsExpr)) {
@@ -112,8 +113,8 @@ lp.parseExprOp = function(left, start, minPrec, noIn, indent, line) {
 lp.parseMaybeUnary = function(sawUnary) {
   let start = this.storeCurrentPos(), expr
   if (this.options.ecmaVersion >= 8 && this.toks.isContextual("await") &&
-    (this.inAsync || (!this.inFunction && this.options.allowAwaitOutsideFunction))
-  ) {
+      (this.inAsync || (this.toks.inModule && this.options.ecmaVersion >= 13) ||
+       (!this.inFunction && this.options.allowAwaitOutsideFunction))) {
     expr = this.parseAwait()
     sawUnary = true
   } else if (this.tok.type.prefix) {
@@ -130,6 +131,8 @@ lp.parseMaybeUnary = function(sawUnary) {
     this.next()
     node.argument = this.parseMaybeUnary(sawUnary)
     expr = this.finishNode(node, "SpreadElement")
+  } else if (!sawUnary && this.tok.type === tt.privateId) {
+    expr = this.parsePrivateIdent()
   } else {
     expr = this.parseExprSubscripts()
     while (this.tok.type.postfix && !this.canInsertSemicolon()) {
@@ -244,8 +247,10 @@ lp.parseExprAtom = function() {
     let id = this.parseIdent()
     let isAsync = false
     if (id.name === "async" && !this.canInsertSemicolon()) {
-      if (this.eat(tt._function))
+      if (this.eat(tt._function)) {
+        this.toks.overrideContext(tokContextTypes.f_expr)
         return this.parseFunction(this.startNodeAt(start), false, true)
+      }
       if (this.tok.type === tt.name) {
         id = this.parseIdent()
         isAsync = true
@@ -302,6 +307,7 @@ lp.parseExprAtom = function() {
     return this.finishNode(node, "ArrayExpression")
 
   case tt.braceL:
+    this.toks.overrideContext(tokContextTypes.b_expr)
     return this.parseObj()
 
   case tt._class:
@@ -507,6 +513,7 @@ lp.parsePropertyName = function(prop) {
 
 lp.parsePropertyAccessor = function() {
   if (this.tok.type === tt.name || this.tok.type.keyword) return this.parseIdent()
+  if (this.tok.type === tt.privateId) return this.parsePrivateIdent()
 }
 
 lp.parseIdent = function() {
@@ -518,6 +525,13 @@ lp.parseIdent = function() {
   return this.finishNode(node, "Identifier")
 }
 
+lp.parsePrivateIdent = function() {
+  const node = this.startNode()
+  node.name = this.tok.value
+  this.next()
+  return this.finishNode(node, "PrivateIdentifier")
+}
+
 lp.initFunction = function(node) {
   node.id = null
   node.params = []
@@ -572,28 +586,31 @@ lp.parseFunctionParams = function(params) {
 }
 
 lp.parseMethod = function(isGenerator, isAsync) {
-  let node = this.startNode(), oldInAsync = this.inAsync, oldInFunction = this.inFunction
+  let node = this.startNode(), oldInAsync = this.inAsync, oldInGenerator = this.inGenerator, oldInFunction = this.inFunction
   this.initFunction(node)
   if (this.options.ecmaVersion >= 6)
     node.generator = !!isGenerator
   if (this.options.ecmaVersion >= 8)
     node.async = !!isAsync
   this.inAsync = node.async
+  this.inGenerator = node.generator
   this.inFunction = true
   node.params = this.parseFunctionParams()
   node.body = this.parseBlock()
   this.toks.adaptDirectivePrologue(node.body.body)
   this.inAsync = oldInAsync
+  this.inGenerator = oldInGenerator
   this.inFunction = oldInFunction
   return this.finishNode(node, "FunctionExpression")
 }
 
 lp.parseArrowExpression = function(node, params, isAsync) {
-  let oldInAsync = this.inAsync, oldInFunction = this.inFunction
+  let oldInAsync = this.inAsync, oldInGenerator = this.inGenerator, oldInFunction = this.inFunction
   this.initFunction(node)
   if (this.options.ecmaVersion >= 8)
     node.async = !!isAsync
   this.inAsync = node.async
+  this.inGenerator = false
   this.inFunction = true
   node.params = this.toAssignableList(params, true)
   node.expression = this.tok.type !== tt.braceL
@@ -604,6 +621,7 @@ lp.parseArrowExpression = function(node, params, isAsync) {
     this.toks.adaptDirectivePrologue(node.body.body)
   }
   this.inAsync = oldInAsync
+  this.inGenerator = oldInGenerator
   this.inFunction = oldInFunction
   return this.finishNode(node, "ArrowFunctionExpression")
 }
