@@ -1,6 +1,6 @@
 // Tests for ECMAScript 7 syntax changes
 
-if (typeof exports != "undefined") {
+if (typeof exports !== "undefined") {
   var test = require("./driver.js").test;
   var testFail = require("./driver.js").testFail;
 }
