@@ -1,8 +1,7 @@
 
-if (typeof exports != "undefined") {
+if (typeof exports !== "undefined") {
   var driver = require("./driver.js");
-  var test = driver.test, testFail = driver.testFail, testAssert = driver.testAssert, misMatch = driver.misMatch;
-  var acorn = require("../acorn");
+  var test = driver.test, testFail = driver.testFail;
 }
 
 //------------------------------------------------------------------------------
